@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler;
 BEGIN {
-  $DBIx::Class::DeploymentHandler::VERSION = '0.001000';
+  $DBIx::Class::DeploymentHandler::VERSION = '0.001001';
 }
 
 # ABSTRACT: Extensible DBIx::Class deployment
@@ -34,17 +34,17 @@ with 'DBIx::Class::DeploymentHandler::WithReasonableDefaults';
 sub prepare_version_storage_install {
   my $self = shift;
 
-  $self->prepare_resultsource_install(
-    $self->version_storage->version_rs->result_source
-  );
+  $self->prepare_resultsource_install({
+    result_source => $self->version_storage->version_rs->result_source
+  });
 }
 
 sub install_version_storage {
   my $self = shift;
 
-  $self->install_resultsource(
-    $self->version_storage->version_rs->result_source
-  );
+  $self->install_resultsource({
+    result_source => $self->version_storage->version_rs->result_source
+  });
 }
 
 sub prepare_install {
@@ -225,7 +225,7 @@ Install the version storage and not the rest of the tables
 
 =head1 AUTHOR
 
-  Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
